# ML Boilerplate

This is a collection of tools and modules which can be used in machine learning.

## CREDIT

The transformers and pipelines in this toolbox are derived from these blog posts from <a href='https://github.com/ramhiser'>Jon Ramey</a> (awaiting permission confirmation) and <a href='https://github.com/tomderuijter'>Tom De Ruijter</a> (awaiting permission confirmation).

Inspiration:
- <a href='https://ramhiser.com/post/2018-04-16-building-scikit-learn-pipeline-with-pandas-dataframe/'>Ramhiser Blog</a>

- <a href='https://medium.com/bigdatarepublic/integrating-pandas-and-scikit-learn-with-pipelines-f70eb6183696'>Tom De Ruijter Medium article</a>
